FnSelect

Trait FnSelect 

pub trait FnSelect: Sized {
    type ValueList;

    // Required method
    fn fn_select(index: u8, values: Self::ValueList) -> Self;
}
Trait for expression types that support select (Fn::Select) expressions

This trait enables generic helper functions for selecting an item from a list across different expression types (ExpString, ExpBool, etc.)

Required Associated Types

type ValueList

The type representing a list of values that can be selected from

Required Methods

fn fn_select(index: u8, values: Self::ValueList) -> Self

Creates a select expression using Fn::Select

Arguments
  • index - Zero-based index of the item to select
  • values - List of values to select from

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors