pub trait FnFindInMap: Sized {
// Required method
fn fn_find_in_map(
map_name: impl Into<MapName>,
top_level_key: impl Into<ExpString>,
second_level_key: impl Into<String>,
) -> Self;
}Expand description
Trait for expression types that support find in map (Fn::FindInMap) expressions
This trait enables generic helper functions for retrieving values from mappings across different expression types (ExpString, ExpBool, etc.)
Required Methods
Sourcefn fn_find_in_map(
map_name: impl Into<MapName>,
top_level_key: impl Into<ExpString>,
second_level_key: impl Into<String>,
) -> Self
fn fn_find_in_map( map_name: impl Into<MapName>, top_level_key: impl Into<ExpString>, second_level_key: impl Into<String>, ) -> Self
Creates a find in map expression using Fn::FindInMap
Arguments
map_name- MapName referencing the mapping to look uptop_level_key- First-level key in the mappingsecond_level_key- Second-level key in the mapping
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.