pub trait FnSelect: Sized {
type ValueList;
// Required method
fn fn_select(index: u8, values: Self::ValueList) -> Self;
}Expand description
Trait for expression types that support select (Fn::Select) expressions
This trait enables generic helper functions for selecting an item from a list across different expression types (ExpString, ExpBool, etc.)
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.